==> estateplat-common-1.2.4-20210727.071042-830-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSmzShzzdm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2021/4/13
 * @description
 */
@Table(name = "xxgx_smz_shzzdm")
public class XxgxSmzShzzdm {

    @Id
    private String shzzdmid;//
    private String tyshxydm;//统一社会信用代码
    private String shzzmc;//社会组织名称
    private String zzlx;//组织类型
    private String shzzlx;//社会组织类型
    private String lxdh;//联系电话
    private String dz;//地址
    private Double zczj;//注册资金
    private String fr;//法人
    private String djlx;//登记类型
    private String frsfz;//法人身份证
    private String proid;//项目ID

    public String getShzzdmid() {
        return shzzdmid;
    }

    public void setShzzdmid(String shzzdmid) {
        this.shzzdmid = shzzdmid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getShzzmc() {
        return shzzmc;
    }

    public void setShzzmc(String shzzmc) {
        this.shzzmc = shzzmc;
    }

    public String getZzlx() {
        return zzlx;
    }

    public void setZzlx(String zzlx) {
        this.zzlx = zzlx;
    }

    public String getShzzlx() {
        return shzzlx;
    }

    public void setShzzlx(String shzzlx) {
        this.shzzlx = shzzlx;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public Double getZczj() {
        return zczj;
    }

    public void setZczj(Double zczj) {
        this.zczj = zczj;
    }

    public String getFr() {
        return fr;
    }

    public void setFr(String fr) {
        this.fr = fr;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getFrsfz() {
        return frsfz;
    }

    public void setFrsfz(String frsfz) {
        this.frsfz = frsfz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20250321.012237-1299-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSmzShzzdm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2021/4/13
 * @description
 */
@Table(name = "xxgx_smz_shzzdm")
public class XxgxSmzShzzdm {

    @Id
    private String shzzdmid;//
    private String tyshxydm;//统一社会信用代码
    private String shzzmc;//社会组织名称
    private String zzlx;//组织类型
    private String shzzlx;//社会组织类型
    private String lxdh;//联系电话
    private String dz;//地址
    private Double zczj;//注册资金
    private String fr;//法人
    private String djlx;//登记类型
    private String frsfz;//法人身份证
    private String proid;//项目ID
    private String qlrmc; //权利人名称
    private String qlrid; //权利人id

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getShzzdmid() {
        return shzzdmid;
    }

    public void setShzzdmid(String shzzdmid) {
        this.shzzdmid = shzzdmid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getShzzmc() {
        return shzzmc;
    }

    public void setShzzmc(String shzzmc) {
        this.shzzmc = shzzmc;
    }

    public String getZzlx() {
        return zzlx;
    }

    public void setZzlx(String zzlx) {
        this.zzlx = zzlx;
    }

    public String getShzzlx() {
        return shzzlx;
    }

    public void setShzzlx(String shzzlx) {
        this.shzzlx = shzzlx;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public Double getZczj() {
        return zczj;
    }

    public void setZczj(Double zczj) {
        this.zczj = zczj;
    }

    public String getFr() {
        return fr;
    }

    public void setFr(String fr) {
        this.fr = fr;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getFrsfz() {
        return frsfz;
    }

    public void setFrsfz(String frsfz) {
        this.frsfz = frsfz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
